<?php if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Theme Actions
 *
 * This is where theme functions are hooked into the appropriate hooks / filters.
 *
 * @since 	1.0.0
 * @author 	WooThemes
 */

// Enqueue Styles
add_action( 'wp_enqueue_scripts', 'jotter_scripts', 30 );

// Move things around
add_action( 'init', 'jotter_setup', 10 );

// Remove some widget regions
add_action( 'init', 'jotter_remove_widgets', 11 );

// Setting overrides
add_filter( 'option_woo_options', 'woo_custom_theme_overrides' );

/**
 * Child Theme Enqueues
 *
 * Enqueues Custom Fonts and Stylesheet files.
 *
 * @since  	1.0.0
 * @return 	void
 * @author 	WooThemes
 */
function jotter_scripts() {
	// Load Theme Stylesheet
	wp_enqueue_style( 'jotter', get_stylesheet_directory_uri() . '/css/jotter.css' );

	// Load JS
	wp_enqueue_script( 'jotter-general', get_stylesheet_directory_uri() . '/js/general.js', array( 'jquery' ) );
	wp_enqueue_script( 'masonry' );

	// Fonts
	wp_enqueue_style( 'crimson-text', '//fonts.googleapis.com/css?family=Crimson+Text:400,400italic,600' );
	wp_enqueue_style( 'merriweather-sans', '//fonts.googleapis.com/css?family=Merriweather+Sans:400,700' );

}

/**
 * Move things around
 *
 * Moves elements from their default location
 *
 * @since  	1.0.0
 * @return 	void
 * @author 	WooThemes
 */
function jotter_setup() {
	unregister_nav_menu( 'top-menu' );

	// Move the nav
	remove_action( 'woo_header_after','woo_nav', 10 );
	add_action( 'woo_header_inside','woo_nav', 10 );

	// Remove the author box
	remove_action( 'wp_head', 'woo_author', 10 );

	// Remove the post nav
	remove_action( 'woo_post_after', 'woo_postnav', 10 );
}

/**
 * Theme Overrides
 *
 * Updates Theme Options dynamically to match the styling of the Child Theme.
 *
 * @since  	1.0.0
 * @return 	array
 * @author 	WooThemes
 */

function woo_custom_theme_overrides( $options ) {
	$sans 		= 'Merriweather Sans';
	$serif 		= 'Crimson Text';

	if ( ! isset( $options['woo_child_theme_overrides'] ) ) {
		$options['woo_child_theme_overrides'] = 'true';
	}

	if ( 'false' != $options['woo_child_theme_overrides'] ) {
		$options['woo_style_disable'] = 'false';

		// Misc
		$options['woo_font_text'] 	= array( 'size' => '1.1', 'unit' => 'em', 'face' => $serif, 'style' => 'normal', 'color' => '#444' );
		$options['woo_font_h1'] 	= array( 'size' => '2.2', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#222' );
		$options['woo_font_h2'] 	= array( 'size' => '1.6', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#222' );
		$options['woo_font_h3'] 	= array( 'size' => '1.3', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#222' );
		$options['woo_font_h4'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#222' );
		$options['woo_font_h5'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#222' );
		$options['woo_font_h6'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#222' );

		// Top Navigation
		$options['woo_top_nav_font'] = array( 'size' => '.9', 'unit' => 'em', 'face' => $serif, 'style' => 'normal', 'color' => '#333333' );

		// Header
		$options['woo_font_logo'] 				= array( 'size' => '2.3', 'unit' => 'em', 'face' => 'Sacramento', 'style' => '400', 'color' => '#333333' );
		$options['woo_font_desc'] 				= array( 'size' => '0.9', 'unit' => 'em', 'face' => $sans, 'style' => 'normal', 'color' => '#666666' );
		$options['woo_header_bg'] 				= '#ffffff';
		$options['woo_header_padding_bottom'] 	= '0';
		$options['woo_header_padding_top'] 		= '0';
		$options['woo_header_cart_link']		= 'false';
		$options['woo_header_cart_total']		= 'false';
		$options['woo_nav_rss']					= 'false';
		$options['woo_subscribe_email']			= false;
		$options['woo_nav_search']				= 'false';

		// Primary Navigation
		$options['woo_nav_font'] 		= array( 'size' => '1', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#333333' );
		$options['woo_nav_bg'] 			= '#ffffff';
		$options['woo_nav_hover_bg'] 	= false;

		// Posts / Pages
		$options['woo_font_post_title'] = array( 'size' => '1.5', 'unit' => 'em', 'face' => $sans, 'style' => '400', 'color' => '#333' );
		$options['woo_font_post_meta'] 	= array( 'size' => '.7', 'unit' => 'em', 'face' => 'Helvetica Neue', 'style' => 'normal', 'color' => '#aaa' );
		$options['woo_font_post_text'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $serif, 'style' => 'normal', 'color' => '#444' );
		$options['woo_font_post_more'] 	= array( 'size' => '.8', 'unit' => 'em', 'face' => 'Helvetica Neue', 'style' => 'normal', 'color' => '#999' );
		$options['woo_pagenav_font'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => 'Helvetica Neue', 'style' => 'normal', 'color' => '#222222' );

		// Post Author
		$options['woo_post_author_border_top'] 		= array( 'width' => '0', 'style' => 'solid', 'color' => '' );
		$options['woo_post_author_border_bottom'] 	= array( 'width' => '0', 'style' => 'solid', 'color' => '' );
		$options['woo_post_author_border_lr'] 		= array( 'width' => '0', 'style' => 'solid', 'color' => '' );
		$options['woo_post_author_border_radius'] 	= '0px';
		$options['woo_post_author_bg'] 				= '#ffffff';

		// Archives
		$options['woo_archive_header_font'] = array( 'size' => '1', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#333' );

		// Widgets
		$options['woo_widget_font_title'] 	= array( 'size' => '1.4', 'unit' => 'em', 'face' => $sans, 'style' => '700', 'color' => '#444' );
		$options['woo_widget_font_text'] 	= array( 'size' => '.9', 'unit' => 'em', 'face' => $serif, 'style' => 'normal', 'color' => '#888888' );
		$options['woo_widget_title_border'] = array( 'width' => '0', 'style' => 'solid', 'color' => '#00000' );

		// Footer
		$options['woo_footer_font'] 	= array( 'size' => '1', 'unit' => 'em', 'face' => $serif, 'style' => 'normal', 'color' => '#7f868a' );
		$options['woo_footer_bg'] 		= '#f6f6f6';

		// Background
		$options['woo_style_bg_image_attach'] = 'fixed';
		$options['woo_style_bg_image_repeat'] = 'repeat';

		// Full Width
		$options['woo_foot_full_width_widget_bg'] 	= '#4C5567';
		$options['woo_footer_full_width_bg'] 		= '#4C5567';
		$options['woo_footer_border_top'] 			= array( 'width' => '0', 'style' => 'solid', 'color' => '#00000' );

	}

	return $options;
}

/**
 * Add Custom Options
 *
 * Add custom options for this Child Theme.
 *
 * @since  	1.0.0
 * @return 	array
 * @author 	WooThemes
 */
function woo_options_add( $options ) {

	$shortname = 'woo';

	$options[] = array( 'name' 		=> __( 'Jotter', 'woothemes' ),
						'icon' 		=> 'misc',
					    'type' 		=> 'heading' );

	$options[] = array( "name" 		=> __( 'Use Child Theme Custom Overrides', 'woothemes' ),
						"desc" 		=> __( 'Disable this option if you\'d like to setup your own typography and layout settings.', 'woothemes' ),
						"id" 		=> $shortname."_child_theme_overrides",
						"std" 		=> "true",
						"type" 		=> "checkbox" );


	return $options;
}

function jotter_remove_widgets(){
	unregister_sidebar( 'footer-1' );
	unregister_sidebar( 'footer-2' );
	unregister_sidebar( 'footer-3' );
	unregister_sidebar( 'footer-4' );
}

// Redefine loop_columns to set 5 products per row
function loop_columns() {
	return 5;
}